@@ -1,7 +1,8 @@
 /*
   Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free
-  Software Foundation, Inc.
+  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
+  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
+  Inc.
 
   This file is part of GNU Inetutils.
 
@@ -118,7 +119,7 @@ void verifydir (char *);
 #endif /* KERBEROS */
 
 #if defined KERBEROS || defined SHISHI
-char *dest_realm = NULL;
+const char *dest_realm = NULL;
 int use_kerberos = 1;
 int doencrypt = 0;
 
@@ -568,7 +569,7 @@ toremote (char *targ, int argc, char *argv[])
 void
 tolocal (int argc, char *argv[])
 {
-  int i, len, tos;
+  int i, tos;
   char *bp, *host, *src, *suser, *vect[1];
 #if defined IP_TOS && defined IPPROTO_IP && defined IPTOS_THROUGHPUT
   struct sockaddr_storage ss;
@@ -580,8 +581,6 @@ tolocal (int argc, char *argv[])
       src = colon (argv[i]);
       if (!src)
 	{			/* Local to local. */
-	  len = strlen (PATH_CP) + strlen (argv[i]) +
-		strlen (target) + 20;
 	  if (asprintf (&bp, "exec %s%s%s %s %s",
 			PATH_CP,
 			iamrecursive ? " -R" : "",
@@ -677,18 +676,18 @@ write_stat_time (int fd, struct stat *stat)
   time_t a_sec, m_sec;
   long a_usec = 0, m_usec = 0;
 
-#ifdef HAVE_STAT_ST_MTIMESPEC
-  a_sec = stat->st_atimespec.ts_sec;
-  a_usec = stat->st_atimespec.ts_nsec / 1000;
-  m_sec = stat->st_mtimespec.ts_sec;
-  m_usec = stat->st_mtimespec.ts_nsec / 1000;
-#else
   a_sec = stat->st_atime;
+#ifdef HAVE_STRUCT_STAT_ST_ATIM_TV_NSEC
+  a_usec = stat->st_atim.tv_nsec / 1000;
+#elif defined HAVE_STRUCT_STAT_ST_ATIM_TV_USEC
+  a_usec = stat->st_atim.tv_usec;
+#endif
+
   m_sec = stat->st_mtime;
-# ifdef HAVE_STAT_ST_MTIME_USEC
-  a_usec = stat->st_atime_usec;
-  m_usec = stat->st_mtime_usec;
-# endif
+#ifdef HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC
+  m_usec = stat->st_mtim.tv_nsec / 1000;
+#elif defined HAVE_STRUCT_STAT_ST_MTIM_TV_USEC
+  m_usec = stat->st_mtim.tv_usec;
 #endif
 
   snprintf (buf, sizeof (buf), "T%ld %ld %ld %ld\n",
@@ -746,7 +745,7 @@ source (int argc, char *argv[])
 	}
 #define RCP_MODEMASK	(S_ISUID|S_ISGID|S_ISVTX|S_IRWXU|S_IRWXG|S_IRWXO)
       snprintf (buf, sizeof buf, "C%04o %jd %s\n",
-		stb.st_mode & RCP_MODEMASK, (intmax_t) stb.st_size, last);
+		(int) stb.st_mode & RCP_MODEMASK, (intmax_t) stb.st_size, last);
       write (rem, buf, strlen (buf));
       if (response () < 0)
 	goto next;
@@ -831,7 +830,7 @@ rsource (char *name, struct stat *statp)
       return;
     }
 
-  sprintf (buf, "D%04o %d %s\n", statp->st_mode & RCP_MODEMASK, 0, last);
+  sprintf (buf, "D%04o %d %s\n", (int) statp->st_mode & RCP_MODEMASK, 0, last);
   write (rem, buf, strlen (buf));
   free (buf);
 
@@ -876,9 +875,9 @@ sink (int argc, char *argv[])
   enum
   { YES, NO, DISPLAYED } wrerr;
   BUF *bp;
-  off_t i, j;
+  off_t i, j, size;
   int amt, count, exists, first, mask, mode, ofd, omode;
-  int setimes, size, targisdir, wrerrno;
+  int setimes, targisdir, wrerrno;
   char ch, *cp, *np, *targ, *vect[1], buf[BUFSIZ];
   const char *why;
 
@@ -995,18 +994,10 @@ sink (int argc, char *argv[])
 	  need = strlen (targ) + strlen (cp) + 250;
 	  if (need > cursize)
 	    {
-	      free (namebuf);
-	      namebuf = malloc (need);
-	      if (namebuf)
-		cursize = need;
-	      else
-		{
-		  run_err ("%s", strerror (errno));
-		  cursize = 0;
-		  continue;
-		}
+	      if (!(namebuf = malloc (need)))
+		run_err ("%s", strerror (errno));
 	    }
-	  snprintf (namebuf, cursize, "%s%s%s", targ, *targ ? "/" : "", cp);
+	  snprintf (namebuf, need, "%s%s%s", targ, *targ ? "/" : "", cp);
 	  np = namebuf;
 	}
       else
