@@ -1,7 +1,8 @@
 /*
   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
   2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012,
-  2013, 2014, 2015 Free Software Foundation, Inc.
+  2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -558,8 +559,9 @@ doit (int f, struct sockaddr *fromp, socklen_t fromlen)
 
 #ifdef HAVE_SETLOGIN
       /* Not sufficient to call setpgid() on BSD systems.  */
-      if (setsid () < 0)
-	syslog (LOG_ERR, "setsid() failed: %m");
+      if (getsid ((pid_t) 0) != getpid ())
+	if (setsid () < 0)
+	  syslog (LOG_ERR, "setsid() failed: %m");
 #elif defined HAVE_SETPGID /* !HAVE_SETLOGIN */
       setpgid (0, getpid ());
 #endif
